@@ -2,6 +2,8 @@ from copy import deepcopy
 from typing import Dict, List, Literal, Optional, Tuple, Union
 
 import requests
+import requests.exceptions
+import urllib3.exceptions
 from tenacity import (
     retry,
     retry_if_exception_type,
@@ -81,14 +83,18 @@ class Query:
     def _get_url(self, verb: Verb) -> str:
         return f"{self.endpoint}/{SERVICE_ID_PREFIX}{self.service_id}/{verb}/{self.namespace}/{self.collection}"
 
-    @retry(
-        retry=retry_if_exception_type(ConnectionResetError),
-        stop=stop_after_attempt(3),
-        wait=wait_exponential(),
-    )
     def _execute_query(self, verb: Verb) -> requests.Response:
         return requests.get(self._get_url(verb), params=self.parameters)
 
+    @retry(
+        retry=(
+            retry_if_exception_type(ConnectionError)
+            | retry_if_exception_type(requests.exceptions.ConnectionError)
+            | retry_if_exception_type(urllib3.exceptions.ProtocolError)
+        ),
+        stop=stop_after_attempt(3),
+        wait=wait_exponential(),
+    )
     def get(self, print_request_url: bool = False) -> dict:
         res: requests.Response = self._execute_query(Verb.GET)
 
@@ -99,6 +105,15 @@ class Query:
 
         return res.json()
 
+    @retry(
+        retry=(
+            retry_if_exception_type(ConnectionError)
+            | retry_if_exception_type(requests.exceptions.ConnectionError)
+            | retry_if_exception_type(urllib3.exceptions.ProtocolError)
+        ),
+        stop=stop_after_attempt(3),
+        wait=wait_exponential(),
+    )
     def count(self, print_request_url: bool = False) -> dict:
         res: requests.Response = self._execute_query(Verb.COUNT)
 
